@@ -36,7 +36,8 @@ G_BEGIN_DECLS
 
 gint                 tracker_data_query_resource_id   (TrackerDataManager  *manager,
                                                        TrackerDBInterface  *iface,
-                                                       const gchar         *uri);
+                                                       const gchar         *uri,
+                                                       GError             **error);
 gchar               *tracker_data_query_unused_uuid   (TrackerDataManager  *manager,
                                                        TrackerDBInterface  *iface);
 
@@ -44,9 +45,10 @@ TrackerDBCursor     *tracker_data_query_sparql_cursor (TrackerDataManager  *mana
                                                        const gchar         *query,
                                                        GError             **error);
 
-GPtrArray*           tracker_data_query_rdf_type      (TrackerDataManager *manager,
-                                                       const gchar        *graph,
-                                                       gint                id);
+GPtrArray*           tracker_data_query_rdf_type      (TrackerDataManager  *manager,
+                                                       const gchar         *graph,
+                                                       gint                 id,
+                                                       GError             **error);
 
 G_END_DECLS
 
