@@ -24,8 +24,6 @@
 #include <libtracker-sparql/tracker-cursor.h>
 #include <libtracker-sparql/tracker-endpoint-dbus.h>
 
-typedef struct _TrackerSparqlConnectionClass TrackerSparqlConnectionClass;
-
 struct _TrackerSparqlConnectionClass
 {
 	GObjectClass parent_class;
@@ -114,8 +112,6 @@ struct _TrackerSparqlConnectionClass
 	                                  gchar                   **path);
 };
 
-typedef struct _TrackerSparqlCursorClass TrackerSparqlCursorClass;
-
 struct _TrackerSparqlCursorClass
 {
 	GObjectClass parent_class;
@@ -145,19 +141,17 @@ struct _TrackerSparqlCursorClass
                                 gint                 column);
         gboolean (* get_boolean) (TrackerSparqlCursor *cursor,
                                   gint                 column);
+        GDateTime* (* get_datetime) (TrackerSparqlCursor *cursor,
+                                     gint                 column);
         gboolean (* is_bound) (TrackerSparqlCursor *cursor,
                                gint                 column);
         gint (* get_n_columns) (TrackerSparqlCursor *cursor);
 };
 
-typedef struct _TrackerEndpointClass TrackerEndpointClass;
-
 struct _TrackerEndpointClass {
 	GObjectClass parent_class;
 };
 
-typedef struct _TrackerEndpointDBus TrackerEndpointDBus;
-
 struct _TrackerEndpointDBus {
 	TrackerEndpoint parent_instance;
 	GDBusConnection *dbus_connection;
@@ -192,15 +186,11 @@ struct _TrackerEndpointHttpClass {
 	struct _TrackerEndpointClass parent_class;
 };
 
-typedef struct _TrackerResourceClass TrackerResourceClass;
-
 struct _TrackerResourceClass
 {
 	GObjectClass parent_class;
 };
 
-typedef struct _TrackerSparqlStatementClass TrackerSparqlStatementClass;
-
 struct _TrackerSparqlStatementClass
 {
 	GObjectClass parent_class;
@@ -217,6 +207,9 @@ struct _TrackerSparqlStatementClass
         void (* bind_double) (TrackerSparqlStatement *stmt,
                               const gchar            *name,
                               gdouble                 value);
+        void (* bind_datetime) (TrackerSparqlStatement *stmt,
+                                const gchar            *name,
+                                GDateTime              *value);
 
         TrackerSparqlCursor * (* execute) (TrackerSparqlStatement  *stmt,
                                            GCancellable            *cancellable,
@@ -231,8 +224,6 @@ struct _TrackerSparqlStatementClass
 	void (* clear_bindings) (TrackerSparqlStatement *stmt);
 };
 
-typedef struct _TrackerNotifierClass TrackerNotifierClass;
-
 struct _TrackerNotifierClass {
 	GObjectClass parent_class;
 
@@ -240,8 +231,6 @@ struct _TrackerNotifierClass {
 	                 const GPtrArray *events);
 };
 
-typedef struct _TrackerBatchClass TrackerBatchClass;
-
 struct _TrackerBatchClass {
 	GObjectClass parent_class;
 
@@ -262,8 +251,6 @@ struct _TrackerBatchClass {
 				     GError       **error);
 };
 
-typedef struct _TrackerSerializerClass TrackerSerializerClass;
-
 struct _TrackerSerializerClass {
 	GInputStreamClass parent_class;
 };
