@@ -390,8 +390,7 @@ export_2to3_with_query (const gchar  *query,
 
 	db_manager = tracker_db_manager_new (TRACKER_DB_MANAGER_READONLY |
 	                                     TRACKER_DB_MANAGER_SKIP_VERSION_CHECK,
-	                                     store,
-	                                     NULL, FALSE,
+	                                     store, FALSE,
 	                                     1, 1, NULL, NULL, NULL, NULL, &inner_error);
 
 	if (inner_error) {
@@ -406,7 +405,7 @@ export_2to3_with_query (const gchar  *query,
 	stmt = tracker_db_interface_create_statement (iface,
 	                                              TRACKER_DB_STATEMENT_CACHE_TYPE_NONE,
 	                                              &inner_error,
-	                                              "%s", query);
+	                                              query);
 	if (!stmt) {
 		g_propagate_prefixed_error (error, inner_error,
 		                            "%s: ", _("Could not run query"));
