@@ -39,9 +39,6 @@ const char usage_string[] =
 	"tracker3 [--version] [--help]\n"
 	"                <command> [<args>]";
 
-const char usage_more_info_string[] =
-	N_("See “tracker3 help <command>” to read about a specific subcommand.");
-
 const char about[] =
 	"Tracker " PACKAGE_VERSION "\n"
 	"\n"
@@ -121,7 +118,7 @@ static void
 handle_command (int argc, const char **argv)
 {
 	char *cmd = g_path_get_basename (argv[0]);
-	int i;
+	guint i;
 
 	for (i = 0; i < G_N_ELEMENTS (commands); i++) {
 		struct cmd_struct *p = commands + i;
@@ -151,7 +148,7 @@ mput_char (char c, unsigned int num)
 static void
 print_usage_list_cmds (void)
 {
-	int i, longest = 0;
+	guint i, longest = 0;
 	GList *extra_commands = NULL;
 	GFileEnumerator *enumerator;
 	GFileInfo *info;
@@ -222,7 +219,7 @@ print_usage (void)
 {
 	g_print ("usage: %s\n\n", usage_string);
 	print_usage_list_cmds ();
-	g_print ("\n%s\n", _(usage_more_info_string));
+	g_print ("\n%s\n", _("See “tracker3 help <command>” to read about a specific subcommand."));
 }
 
 int
